@@ -7,12 +7,13 @@ class SynoDSMNetwork(object):
 
     API_KEY = "SYNO.DSM.Network"
 
-    def __init__(self, raw_data):
+    def __init__(self, dsm):
+        self._dsm = dsm
         self._data = {}
-        self.update(raw_data)
 
-    def update(self, raw_data):
+    def update(self):
         """Updates network data."""
+        raw_data = self._dsm.get(self.API_KEY, "list")
         if raw_data:
             self._data = raw_data["data"]
 
